- [X] async build
- [X] cancel build
- [X] agnostic build system (Gemini, HTML)
- [X] only build if needed
- [X] remove url from config (HTML concept)
- [X] feed.gmi
- [X] post.gmi with metadata (back, date, author)
- [X] tags
- [X] base URL in gemini
- [X] categories
- [X] nb init: copy templates based on configured builders
- [X] nb new
- [X] nb publish
- [X] html builder with atom
- [X] antenna announcer
- [X] geminiinfo announcer
- [X] freeze announce-on
- [X] builder path
- [X] publisher path
- [X] add enclosures to post
- [X] CAPCOM announcer
- [X] atom: <link rel="alternate" type="text/gemini" href="gemini://..." /> ?
- [X] add grace period to announcers, to prevent spamming
- [X] remove scope from builder, move to announcer
- [X] mastodon announcer
- [X] reading time assistant
- [X] validate config
- [X] weather assistant
- [X] playlist assistant
- [X] archive links (post) assistant
- [X] migrate to marko
- [X] mirror images (post) assistant
- [X] html templates (with striptags|e)
- [X] S3 publisher
- [X] rename URI to URL
- [X] webmention announcer
- [X] fix multi line blockquotes
- [X] calendar assistant for RSVP events
- [X] archive links should archive post and site as well!
- [ ] nncp publisher
- [/] single post actions
- [/] dither assistant
- [/] use yarl (post?)
- [?] templates in Atom feed
- [ ] hcard (photo and index)
- [ ] add OG metadata (reading from post.metadata.meta?)
- [ ] Twitter announcer/assistant (for card)
- [ ] music player
- [ ] display replies
- [ ] warn on external resources (site) assistant
- [ ] announcer staleness (don't collect if post is older than 7 days, eg)
- [?] NeoCities publisher
